# ~ Area4 Package by RDIL ~

# Imports:
import random

# Package info variables:
name = "area4"
author = "https://github.com/RDIL"
author_email = "contactspaceboom@gmail.com"
description = "Dividers in Python, the easy way! Multiple different divider looks."

# Divider variables:
divider1 = str("------------------------")
divider2 = str("________________________")
divider3 = str("........................")
divider4 = str("⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛")
divider5 = str("⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️")
divider6 = str("⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️")
divider7 = str("========================")
divider8 = str("########################")
divider9 = str("************************")
divider10 = str(",,,,,,,,,,,,,,,,,,,,,,,,")
divider11 = str("////////////////////////")
divider12 = str("||||||||||||||||||||||||")
divider13 = str("~~~~~~~~~~~~~~~~~~~~~~~~")
divider14 = str("\\\\\\\\\\\\\\\\\\\\\\\\")
divider15 = str("☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕")
divider16 = str("++++++++++++++++++++++++")
divider17 = str("r(`,,,`)r r(`,,,`)r r(`,,,`)r ")
divider18 = str("( ͡° ͜ʖ ͡°)( ͡° ͜ʖ ͡°)( ͡° ͜ʖ ͡°)( ͡° ͜ʖ ͡°)")
divider19 = str("&&&&&&&&&&&&&&&&&&&&&&&&&")
divider20 = str("^^^^^^^^^^^^^^^^^^^^^^^^^")
divider21 = str("¯\_(ツ)_/¯ ¯\_(ツ)_/¯ ¯\_(ツ)_/¯ ¯\_(ツ)_/¯")
divider22 = str("11111111111111111111111")
divider23 = str("22222222222222222222222")
divider24 = str("33333333333333333333333")
divider25 = str("44444444444444444444444")
divider26 = str("55555555555555555555555")
divider27 = str("66666666666666666666666")
divider28 = str("77777777777777777777777")
divider29 = str("88888888888888888888888")
divider30 = str("99999999999999999999999")
divider31 = str("1010101010101010101010")
divider32 = str("<><><><><><><><><><><>")
divider33 = str("^,^,^,^,^,^,^,^,^,^,^,^")
divider34 = str("&*&*&*&*&*&*&*&*&*&*&*&")
divider35 = str(random.randint(0, 99999999999999999999999))
divider36 = str("```````````````````````")
divider37 = str("aaaaaaaaaaaa")
divider38 = str("AAAAAAAAAAAA")
divider39 = str("bbbbbbbbbbbb")
divider40 = str("BBBBBBBBBBBB")
divider41 = str("cccccccccccc")
divider42 = str("CCCCCCCCCCCC")
divider43 = str("dddddddddddd")
divider44 = str("DDDDDDDDDDDD")
divider45 = str("eeeeeeeeeeee")
divider46 = str("EEEEEEEEEEEE")
divider47 = str("ffffffffffff")
divider48 = str("FFFFFFFFFFFF")
divider49 = str("gggggggggggg")
divider50 = str("GGGGGGGGGGGG")
divider51 = str("hhhhhhhhhhhh")
divider52 = str("HHHHHHHHHHHH")
divider53 = str("iiiiiiiiiiii")
divider54 = str("IIIIIIIIIIII")
divider55 = str("jjjjjjjjjjjj")
divider56 = str("JJJJJJJJJJJJ")
divider57 = str("kkkkkkkkkkkk")
divider58 = str("KKKKKKKKKKKK")
divider59 = str("llllllllllll")
divider60 = str("LLLLLLLLLLLL")
divider61 = str("mmmmmmmmmmmm")
divider62 = str("MMMMMMMMMMMM")
divider63 = str("nnnnnnnnnnnn")
divider64 = str("NNNNNNNNNNNN")
divider65 = str("oooooooooooo")
divider66 = str("OOOOOOOOOOOO")
divider67 = str("pppppppppppp")
divider68 = str("PPPPPPPPPPPP")
divider69 = str("qqqqqqqqqqqq")
divider70 = str("QQQQQQQQQQQQ")
divider71 = str("rrrrrrrrrrrr")
divider72 = str("RRRRRRRRRRRR")
divider73 = str("ssssssssssss")
divider74 = str("SSSSSSSSSSSS")
divider75 = str("tttttttttttt")
divider76 = str("TTTTTTTTTTTT")
divider77 = str("uuuuuuuuuuuu")
divider78 = str("UUUUUUUUUUUU")
divider79 = str("vvvvvvvvvvvv")
divider80 = str("VVVVVVVVVVVV")
divider81 = str("wwwwwwwwwwww")
divider82 = str("WWWWWWWWWWWW")
divider83 = str("xxxxxxxxxxxx")
divider84 = str("XXXXXXXXXXXX")
divider85 = str("yyyyyyyyyyyy")
divider86 = str("YYYYYYYYYYYY")
divider87 = str("zzzzzzzzzzzz")
divider88 = str("ZZZZZZZZZZZZ")
divider89 = str("🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️")
divider90 = str("✈️✈️✈️✈️✈️✈️✈️✈️✈️✈️✈️✈️")
divider91 = str("🍂🍂🍂🍂🍂🍂🍂🍂🍂🍂🍂🍂")
divider92 = str("🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️")
divider93 = str("😀😀😀😀😀😀😀😀😀😀😀😀")
divider94 = str("😂😂😂😂😂😂😂😂😂😂😂😂")
divider95 = str("😛😛😛😛😛😛😛😛😛😛😛😛")
divider96 = str("😝😝😝😝😝😝😝😝😝😝😝😝")
divider97 = str("😨😨😨😨😨😨😨😨😨😨😨😨")
divider98 = str("😩😩😩😩😩😩😩😩😩😩😩😩")
divider99 = str("😬😬😬😬😬😬😬😬😬😬😬😬")
divider100 = str("😰😰😰😰😰😰😰😰😰😰😰😰")
divider101 = str("😱😱😱😱😱😱😱😱😱😱😱😱")
divider102 = str("👶👶👶👶👶👶👶👶👶👶👶👶")
divider103 = str("👧👧👧👧👧👧👧👧👧👧👧👧")
divider104 = str("👦👦👦👦👦👦👦👦👦👦👦👦")
divider105 = str("👩👩👩👩👩👩👩👩👩👩👩👩")
divider106 = str("👨👨👨👨👨👨👨👨👨👨👨👨")
divider107 = str("👵👵👵👵👵👵👵👵👵👵👵👵")
divider108 = str("👴👴👴👴👴👴👴👴👴👴👴👴")
divider109 = str("👍👍👍👍👍👍👍👍👍👍👍👍")
divider110 = str("👎👎👎👎👎👎👎👎👎👎👎👎")
divider111 = str("👊👊👊👊👊👊👊👊👊👊👊👊")
divider112 = str("✊✊✊✊✊✊✊✊✊✊✊✊")
divider113 = str("🤛🤛🤛🤛🤛🤛🤛🤛🤛🤛🤛🤛")
divider114 = str("🤜🤜🤜🤜🤜🤜🤜🤜🤜🤜🤜🤜")
divider115 = str("🤞🤞🤞🤞🤞🤞🤞🤞🤞🤞🤞🤞")
divider116 = str("✌✌✌✌✌✌✌✌✌✌✌✌")
divider117 = str("🤘🤘🤘🤘🤘🤘🤘🤘🤘🤘🤘🤘")
divider118 = str("👌👌👌👌👌👌👌👌👌👌👌👌")
divider119 = str("👈👈👈👈👈👈👈👈👈👈👈👈")
divider120 = str("👉👉👉👉👉👉👉👉👉👉👉👉")
divider121 = str("👆👆👆👆👆👆👆👆👆👆👆👆")
divider122 = str("👇👇👇👇👇👇👇👇👇👇👇👇")
divider123 = str("☝☝☝☝☝☝☝☝☝☝☝☝")
divider124 = str("✋✋✋✋✋✋✋✋✋✋✋✋")
divider125 = str("🤚🤚🤚🤚🤚🤚🤚🤚🤚🤚🤚🤚")
divider126 = str("🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐")
divider127 = str("🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖")
divider128 = str("👋👋👋👋👋👋👋👋👋👋👋👋")
divider129 = str("🤙🤙🤙🤙🤙🤙🤙🤙🤙🤙🤙🤙")
divider130 = str("💪💪💪💪💪💪💪💪💪💪💪💪")
divider131 = str("🐶🐶🐶🐶🐶🐶🐶🐶🐶🐶🐶🐶")
divider132 = str("🐱🐱🐱🐱🐱🐱🐱🐱🐱🐱🐱🐱")
divider133 = str("🐭🐭🐭🐭🐭🐭🐭🐭🐭🐭🐭🐭")
divider134 = str("🐹🐹🐹🐹🐹🐹🐹🐹🐹🐹🐹🐹")
divider135 = str("🐰🐰🐰🐰🐰🐰🐰🐰🐰🐰🐰🐰")
divider136 = str("🦊🦊🦊🦊🦊🦊🦊🦊🦊🦊🦊🦊")
divider137 = str("🐻🐻🐻🐻🐻🐻🐻🐻🐻🐻🐻🐻")
divider138 = str("🐼🐼🐼🐼🐼🐼🐼🐼🐼🐼🐼🐼")
divider139 = str("🐨🐨🐨🐨🐨🐨🐨🐨🐨🐨🐨🐨")
divider140 = str("🐯🐯🐯🐯🐯🐯🐯🐯🐯🐯🐯🐯")
divider141 = str("🦁🦁🦁🦁🦁🦁🦁🦁🦁🦁🦁🦁")
divider142 = str("🐮🐮🐮🐮🐮🐮🐮🐮🐮🐮🐮🐮")
divider143 = str("🐷🐷🐷🐷🐷🐷🐷🐷🐷🐷🐷🐷")
divider144 = str("🐸🐸🐸🐸🐸🐸🐸🐸🐸🐸🐸🐸")
divider145 = str("🐵🐵🐵🐵🐵🐵🐵🐵🐵🐵🐵🐵")
divider146 = str("🙈🙈🙈🙈🙈🙈🙈🙈🙈🙈🙈🙈")
divider147 = str("🙉🙉🙉🙉🙉🙉🙉🙉🙉🙉🙉🙉")
divider148 = str("🙊🙊🙊🙊🙊🙊🙊🙊🙊🙊🙊🙊")
divider149 = str("🐒🐒🐒🐒🐒🐒🐒🐒🐒🐒🐒🐒")
divider150 = str("🐧🐧🐧🐧🐧🐧🐧🐧🐧🐧🐧🐧")
divider151 = str("🐔🐔🐔🐔🐔🐔🐔🐔🐔🐔🐔🐔")
divider152 = str("🐦🐦🐦🐦🐦🐦🐦🐦🐦🐦🐦🐦")
divider153 = str("🐤🐤🐤🐤🐤🐤🐤🐤🐤🐤🐤🐤")
divider154 = str("🐣🐣🐣🐣🐣🐣🐣🐣🐣🐣🐣🐣")
divider155 = str("🐥🐥🐥🐥🐥🐥🐥🐥🐥🐥🐥🐥")
divider156 = str("🦆🦆🦆🦆🦆🦆🦆🦆🦆🦆🦆🦆")
divider157 = str("💐💐💐💐💐💐💐💐💐💐💐💐")
divider158 = str("🌷🌷🌷🌷🌷🌷🌷🌷🌷🌷🌷🌷")
divider159 = str("🌹🌹🌹🌹🌹🌹🌹🌹🌹🌹🌹🌹")
divider160 = str("🥀🥀🥀🥀🥀🥀🥀🥀🥀🥀🥀🥀")
divider161 = str("🌺🌺🌺🌺🌺🌺🌺🌺🌺🌺🌺🌺")
divider162 = str("🌸🌸🌸🌸🌸🌸🌸🌸🌸🌸🌸🌸")
divider163 = str("🌼🌼🌼🌼🌼🌼🌼🌼🌼🌼🌼🌼")
divider164 = str("🌻🌻🌻🌻🌻🌻🌻🌻🌻🌻🌻🌻")
divider165 = str("🌞🌞🌞🌞🌞🌞🌞🌞🌞🌞🌞🌞")
divider166 = str("🌝🌝🌝🌝🌝🌝🌝🌝🌝🌝🌝🌝")
divider167 = str("🌛🌛🌛🌛🌛🌛🌛🌛🌛🌛🌛🌛")
divider168 = str("🌜🌜🌜🌜🌜🌜🌜🌜🌜🌜🌜🌜")
divider169 = str("🌚🌚🌚🌚🌚🌚🌚🌚🌚🌚🌚🌚")
divider170 = str("🌟🌟🌟🌟🌟🌟🌟🌟🌟🌟🌟🌟")
divider171 = str("✨✨✨✨✨✨✨✨✨✨✨✨")
divider172 = str("⚡⚡⚡⚡⚡⚡⚡⚡⚡⚡⚡⚡")
divider173 = str("☄️☄️☄️☄️☄️☄️☄️☄️☄️☄️☄️☄️")
divider174 = str("🔥🔥🔥🔥🔥🔥🔥🔥🔥🔥🔥🔥")
divider175 = str("🌪🌪🌪🌪🌪🌪🌪🌪🌪🌪🌪🌪")
divider176 = str("🌈🌈🌈🌈🌈🌈🌈🌈🌈🌈🌈🌈")
divider177 = str("🍗🍗🍗🍗🍗🍗🍗🍗🍗🍗🍗🍗")
divider178 = str("🍖🍖🍖🍖🍖🍖🍖🍖🍖🍖🍖🍖")
divider179 = str("🌭🌭🌭🌭🌭🌭🌭🌭🌭🌭🌭🌭")
divider180 = str("🍔🍔🍔🍔🍔🍔🍔🍔🍔🍔🍔🍔")
divider181 = str("🍟🍟🍟🍟🍟🍟🍟🍟🍟🍟🍟🍟")
divider182 = str("🍕🍕🍕🍕🍕🍕🍕🍕🍕🍕🍕🍕")
divider183 = str("🥪🥪🥪🥪🥪🥪🥪🥪🥪")
divider184 = str("🍧🍧🍧🍧🍧🍧🍧🍧🍧🍧🍧🍧")
divider185 = str("🍨🍨🍨🍨🍨🍨🍨🍨🍨🍨🍨🍨")
divider186 = str("🍦🍦🍦🍦🍦🍦🍦🍦🍦🍦🍦🍦")
divider187 = str("🥧🥧🥧🥧🥧🥧🥧🥧🥧")
divider188 = str("🍰🍰🍰🍰🍰🍰🍰🍰🍰🍰🍰🍰")
divider189 = str("🎂🎂🎂🎂🎂🎂🎂🎂🎂🎂🎂🎂")
divider190 = str("🍺🍺🍺🍺🍺🍺🍺🍺🍺🍺🍺🍺")
divider191 = str("🍻🍻🍻🍻🍻🍻🍻🍻🍻🍻🍻🍻")
divider192 = str("🥂🥂🥂🥂🥂🥂🥂🥂🥂🥂🥂🥂")
divider193 = str("🍷🍷🍷🍷🍷🍷🍷🍷🍷🍷🍷🍷")
divider194 = str("⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽")
divider195 = str("🥇🥇🥇🥇🥇🥇🥇🥇🥇🥇🥇🥇")
divider196 = str("🚗🚗🚗🚗🚗🚗🚗🚗🚗🚗🚗🚗")
divider197 = str("⏰⏰⏰⏰⏰⏰⏰⏰⏰⏰⏰⏰")
divider198 = str("💰💰💰💰💰💰💰💰💰💰💰💰")
divider199 = str("🎈🎈🎈🎈🎈🎈🎈🎈🎈🎈🎈🎈")
divider200 = str("❤️❤️❤️❤️❤️❤️❤️❤️❤️❤️")

custom_div = str("")

# Functions:
def div1():
	"""
	Returns the divider ------------------------

	:return: divider1
	"""
	return divider1

def div2():
	"""
	Returns the divider ________________________
	:return: divider2
	"""

	return divider2

def div3():
	"""
	Returns the divider ........................

	:return: divider3
	"""

	return divider3

def div4():
	"""
	Returns the divider ⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛⬛

	:return: divider4
	"""

	return divider4

def div5():
	"""
	Returns the divider ⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️⬆️

	:return: divider5
	"""

	return divider5

def div6():
	"""
	Returns the divider ⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️⬇️

	:return: divider6
	"""

	return divider6

def div7():
	"""
	Returns the divider ========================

	:return: divider7
	"""

	return divider7

def div8():
	"""
	Returns the divider ########################

	:return: divider8
	"""

	return divider8

def div9():
	"""
	Returns the divider ************************

	:return: divider9
	"""

	return divider9

def div10():
	"""
	Returns the divider ,,,,,,,,,,,,,,,,,,,,,,,,

	:return: divider10
	"""

	return divider10

def div11():
	"""
	Returns the divider ////////////////////////

	:return: divider11
	"""

	return divider11

def div12():
	"""
	Returns the divider ||||||||||||||||||||||||

	:return: divider12
	"""

	return divider12

def div13():
	"""
	Returns the divider ~~~~~~~~~~~~~~~~~~~~~~~~

	:return: divider13
	"""

	return divider13

def div14():
	"""
	Returns the divider \\\\\\\\\\\\\\\\\\\\\\\\

	:return: divider14
	"""

	return divider14

def div15():
	"""
	Returns the divider ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕ ☕

	:return: divider15
	"""

	return divider15

def div16():
	"""
	Returns the divider ++++++++++++++++++++++++

	:return: divider16
	"""

	return divider16

def div17():
	"""
	Returns the divider r(`,,,`)r r(`,,,`)r r(`,,,`)r

	:return: divider17
	"""

	return divider17

def div18():
	"""
	Returns the divider ( ͡° ͜ʖ ͡°)( ͡° ͜ʖ ͡°)( ͡° ͜ʖ ͡°)( ͡° ͜ʖ ͡°)

	:return: divider18
	"""

	return divider18

def div19():
	"""
	Returns the divider &&&&&&&&&&&&&&&&&&&&&&&&&

	:return: divider19
	"""

	return divider19

def div20():
	"""
	Returns the divider ^^^^^^^^^^^^^^^^^^^^^^^^^

	:return: divider20
	"""

	return divider20

def div21():
	"""
	Returns the divider ¯\_(ツ)_/¯ ¯\_(ツ)_/¯ ¯\_(ツ)_/¯ ¯\_(ツ)_/¯

	:return: divider21
	"""

	return divider21

def div22():
	"""
	Returns the divider 11111111111111111111111

	:return: divider22
	"""

	return divider22

def div23():
	"""
	Returns the divider 22222222222222222222222

	:return: divider23
	"""

	return divider23

def div24():
	"""
	Returns the divider 33333333333333333333333

	:return: divider24
	"""

	return divider24

def div25():
	"""
	Returns the divider 44444444444444444444444

	:return: divider25
	"""

	return divider25

def div26():
	"""
	Returns the divider 55555555555555555555555

	:return: divider26
	"""

	return divider26

def div27():
	"""
	Returns the divider 66666666666666666666666

	:return: divider27
	"""

	return divider27

def div28():
	"""
	Returns the divider 77777777777777777777777

	:return: divider28
	"""

	return divider28

def div29():
	"""
	Returns the divider 88888888888888888888888

	:return: divider29
	"""

	return divider29

def div30():
	"""
	Returns the divider 99999999999999999999999

	:return: divider30
	"""

	return divider30

def div31():
	"""
	Returns the divider 1010101010101010101010

	:return: divider31
	"""

	return divider31

def div32():
	"""
	Returns the divider <><><><><><><><><><><>

	:return: divider32
	"""

	return divider32

def div33():
	"""
	Returns the divider ^,^,^,^,^,^,^,^,^,^,^,^

	:return: divider33
	"""

	return divider33

def div34():
	"""
	Returns the divider &*&*&*&*&*&*&*&*&*&*&*&

	:return: divider34
	"""

	return divider34

def div35():
	"""
	Returns the divider random.randint(0, 99999999999999999999999)

	:return: divider35
	"""

	return divider35

def div36():
	"""
	Returns the divider ```````````````````````

	:return: divider36
	"""

	return divider36

def div37():
	"""
	Returns the divider aaaaaaaaaaaa

	:return: divider37
	"""

	return divider37

def div38():
	"""
	Returns the divider AAAAAAAAAAAA

	:return: divider38
	"""

	return divider38

def div39():
	"""
	Returns the divider bbbbbbbbbbbb

	:return: divider39
	"""

	return divider39

def div40():
	"""
	Returns the divider BBBBBBBBBBBB

	:return: divider40
	"""

	return divider40

def div41():
	"""
	Returns the divider cccccccccccc

	:return: divider41
	"""

	return divider41

def div42():
	"""
	Returns the divider CCCCCCCCCCCC

	:return: divider42
	"""

	return divider42

def div43():
	"""
	Returns the divider dddddddddddd

	:return: divider43
	"""

	return divider43

def div44():
	"""
	Returns the divider DDDDDDDDDDDD

	:return: divider44
	"""

	return divider44

def div45():
	"""
	Returns the divider eeeeeeeeeeee

	:return: divider45
	"""

	return divider45

def div46():
	"""
	Returns the divider EEEEEEEEEEEE

	:return: divider46
	"""

	return divider46

def div47():
	"""
	Returns the divider ffffffffffff

	:return: divider47
	"""

	return divider47

def div48():
	"""
	Returns the divider FFFFFFFFFFFF

	:return: divider48
	"""

	return divider48

def div49():
	"""
	Returns the divider gggggggggggg

	:return: divider49
	"""

	return divider49

def div50():
	"""
	Returns the divider GGGGGGGGGGGG

	:return: divider50
	"""

	return divider50

def div51():
	"""
	Returns the divider hhhhhhhhhhhh

	:return: divider51
	"""

	return divider51

def div52():
	"""
	Returns the divider HHHHHHHHHHHH

	:return: divider52
	"""

	return divider52

def div53():
	"""
	Returns the divider iiiiiiiiiiii

	:return: divider53
	"""

	return divider53

def div54():
	"""
	Returns the divider IIIIIIIIIIII

	:return: divider54
	"""

	return divider54

def div55():
	"""
	Returns the divider jjjjjjjjjjjj

	:return: divider55
	"""

	return divider55

def div56():
	"""
	Returns the divider JJJJJJJJJJJJ

	:return: divider56
	"""

	return divider56

def div57():
	"""
	Returns the divider kkkkkkkkkkkk

	:return: divider57
	"""

	return divider57

def div58():
	"""
	Returns the divider KKKKKKKKKKKK

	:return: divider58
	"""

	return divider58

def div59():
	"""
	Returns the divider llllllllllll

	:return: divider59
	"""

	return divider59

def div60():
	"""
	Returns the divider LLLLLLLLLLLL

	:return: divider60
	"""

	return divider60

def div61():
	"""
	Returns the divider mmmmmmmmmmmm

	:return: divider61
	"""

	return divider61

def div62():
	"""
	Returns the divider MMMMMMMMMMMM

	:return: divider62
	"""

	return divider62

def div63():
	"""
	Returns the divider nnnnnnnnnnnn

	:return: divider63
	"""

	return divider63

def div64():
	"""
	Returns the divider NNNNNNNNNNNN

	:return: divider64
	"""

	return divider64

def div65():
	"""
	Returns the divider oooooooooooo

	:return: divider65
	"""

	return divider65

def div66():
	"""
	Returns the divider OOOOOOOOOOOO

	:return: divider66
	"""

	return divider66

def div67():
	"""
	Returns the divider pppppppppppp

	:return: divider67
	"""

	return divider67

def div68():
	"""
	Returns the divider PPPPPPPPPPPP

	:return: divider68
	"""

	return divider68

def div69():
	"""
	Returns the divider qqqqqqqqqqqq

	:return: divider69
	"""

	return divider69

def div70():
	"""
	Returns the divider QQQQQQQQQQQQ

	:return: divider70
	"""

	return divider70

def div71():
	"""
	Returns the divider rrrrrrrrrrrr

	:return: divider71
	"""

	return divider71

def div72():
	"""
	Returns the divider RRRRRRRRRRRR

	:return: divider72
	"""

	return divider72

def div73():
	"""
	Returns the divider ssssssssssss

	:return: divider73
	"""

	return divider73

def div74():
	"""
	Returns the divider SSSSSSSSSSSS

	:return: divider74
	"""

	return divider74

def div75():
	"""
	Returns the divider tttttttttttt

	:return: divider75
	"""

	return divider75

def div76():
	"""
	Returns the divider TTTTTTTTTTTT

	:return: divider76
	"""

	return divider76

def div77():
	"""
	Returns the divider uuuuuuuuuuuu

	:return: divider77
	"""

	return divider77

def div78():
	"""
	Returns the divider UUUUUUUUUUUU

	:return: divider78
	"""

	return divider78

def div79():
	"""
	Returns the divider vvvvvvvvvvvv

	:return: divider79
	"""

	return divider79

def div80():
	"""
	Returns the divider VVVVVVVVVVVV

	:return: divider80
	"""

	return divider80

def div81():
	"""
	Returns the divider wwwwwwwwwwww

	:return: divider81
	"""

	return divider81

def div82():
	"""
	Returns the divider WWWWWWWWWWWW

	:return: divider82
	"""

	return divider82

def div83():
	"""
	Returns the divider xxxxxxxxxxxx

	:return: divider83
	"""

	return divider83

def div84():
	"""
	Returns the divider XXXXXXXXXXXX

	:return: divider84
	"""

	return divider84

def div85():
	"""
	Returns the divider yyyyyyyyyyyy

	:return: divider85
	"""

	return divider85

def div86():
	"""
	Returns the divider YYYYYYYYYYYY

	:return: divider86
	"""

	return divider86

def div87():
	"""
	Returns the divider zzzzzzzzzzzz

	:return: divider87
	"""

	return divider87

def div88():
	"""
	Returns the divider ZZZZZZZZZZZZ

	:return: divider88
	"""

	return divider88

def div89():
	"""
	Returns the divider 🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️🏖️

	:return: divider89
	"""

	return divider89

def div90():
	"""
	Returns the divider ✈️✈️✈️✈️✈️✈️✈️✈️✈️✈️✈️✈️

	:return: divider90
	"""

	return divider90

def div91():
	"""
	Returns the divider 🍂🍂🍂🍂🍂🍂🍂🍂🍂🍂🍂🍂

	:return: divider91
	"""

	return divider91

def div92():
	"""
	Returns the divider 🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️🗝️

	:return: divider92
	"""

	return divider92

def div93():
	"""
	Returns the divider 😀😀😀😀😀😀😀😀😀😀😀😀

	:return: divider93
	"""

	return divider93
def div94():
	"""
	Returns the divider 😂😂😂😂😂😂😂😂😂😂😂😂

	:return: divider94
	"""

	return divider94
def div95():
	"""
	Returns the divider 😛😛😛😛😛😛😛😛😛😛😛😛

	:return: divider95
	"""

	return divider95

def div96():
	"""
	Returns the divider 😝😝😝😝😝😝😝😝😝😝😝😝😝

	:return: divider96
	"""

	return divider96

def div97():
	"""
	Returns the divider 😨😨😨😨😨😨😨😨😨😨😨😨

	:return: divider97
	"""

	return divider97

def div98():
	"""
	Returns the divider 😩😩😩😩😩😩😩😩😩😩😩😩

	:return: divider98
	"""

	return divider98

def div99():
	"""
	Returns the divider 😬😬😬😬😬😬😬😬😬😬😬😬

	:return: divider99
	"""

	return divider99
def div100():
	"""
	Returns the divider 😰😰😰😰😰😰😰😰😰😰😰😰

	:return: divider100
	"""

	return divider100

def div101():
	"""
	Returns the divider 😱😱😱😱😱😱😱😱😱😱😱😱

	:return: divider101
	"""

	return divider101

def div102():
	"""
	Returns the divider 👶👶👶👶👶👶👶👶👶👶👶👶

	:return: divider102
	"""

	return divider102

def div103():
	"""
	Returns the divider 👧👧👧👧👧👧👧👧👧👧👧👧

	:return: divider103
	"""

	return divider103

def div104():
	"""
	Returns the divider 👦👦👦👦👦👦👦👦👦👦👦👦

	:return: divider104
	"""

	return divider104

def div105():
	"""
	Returns the divider 👩👩👩👩👩👩👩👩👩👩👩👩


	:return: divider105
	"""

	return divider105

def div106():
	"""
	Returns the divider 👨👨👨👨👨👨👨👨👨👨👨👨

	:return: divider106
	"""

	return divider106

def div107():
	"""
	Returns the divider 👵👵👵👵👵👵👵👵👵👵👵👵

	:return: divider107
	"""

	return divider107

def div108():
	"""
	Returns the divider 👴👴👴👴👴👴👴👴👴👴👴👴

	:return: divider108
	"""

	return divider108

def div109():
	"""
	Returns the divider 👍👍👍👍👍👍👍👍👍👍👍👍

	:return: divider109
	"""

	return divider109

def div110():
	"""
	Returns the divider 👎👎👎👎👎👎👎👎👎👎👎👎

	:return: divider110
	"""

	return divider110

def div111():
	"""
	Returns the divider 👊👊👊👊👊👊👊👊👊👊👊👊

	:return: divider111
	"""

	return divider111


def div112():
	"""
	Returns the divider ✊✊✊✊✊✊✊✊✊✊✊✊

	:return: divider112
	"""

	return divider112

def div113():
	"""
	Returns the divider 🤛🤛🤛🤛🤛🤛🤛🤛🤛🤛🤛🤛

	:return: divider113
	"""

	return divider113

def div114():
	"""
	Returns the divider 🤜🤜🤜🤜🤜🤜🤜🤜🤜🤜🤜🤜

	:return: divider114
	"""

	return divider114

def div115():
	"""
	Returns the divider 🤞🤞🤞🤞🤞🤞🤞🤞🤞🤞🤞🤞

	:return: divider115
	"""

	return divider115

def div116():
	"""
	Returns the divider ✌✌✌✌✌✌✌✌✌✌✌✌

	:return: divider116
	"""

	return divider116

def div117():
	"""
	Returns the divider 🤘🤘🤘🤘🤘🤘🤘🤘🤘🤘🤘🤘

	:return: divider117
	"""

	return divider117

def div118():
	"""
	Returns the divider 👌👌👌👌👌👌👌👌👌👌👌👌

	:return: divider118
	"""

	return divider118

def div119():
	"""
	Returns the divider 👈👈👈👈👈👈👈👈👈👈👈👈

	:return: divider119
	"""

	return divider119

def div120():
	"""
	Returns the divider 👉👉👉👉👉👉👉👉👉👉👉👉

	:return: divider120
	"""

	return divider120

def div121():
	"""
	Returns the divider 👆👆👆👆👆👆👆👆👆👆👆👆

	:return: divider121
	"""

	return divider121

def div122():
	"""
	Returns the divider 👇👇👇👇👇👇👇👇👇👇👇👇

	:return: divider122
	"""

	return divider122

def div123():
	"""
	Returns the divider ☝☝☝☝☝☝☝☝☝☝☝☝

	:return: divider123
	"""

	return divider123

def div124():
	"""
	Returns the divider ✋✋✋✋✋✋✋✋✋✋✋✋

	:return: divider124
	"""

	return divider124

def div125():
	"""
	Returns the divider 🤚🤚🤚🤚🤚🤚🤚🤚🤚🤚🤚🤚

	:return: divider125
	"""

	return divider125

def div126():
	"""
	Returns the divider 🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐🖐

	:return: divider126
	"""

	return divider126

def div127():
	"""
	Returns the divider 🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖🖖

	:return: divider127
	"""

	return divider127

def div128():
	"""
	Returns the divider 👋👋👋👋👋👋👋👋👋👋👋👋

	:return: divider128
	"""

	return divider128

def div129():
	"""
	Returns the divider 🤙🤙🤙🤙🤙🤙🤙🤙🤙🤙🤙🤙

	:return: divider129
	"""

	return divider129

def div130():
	"""
	Returns the divider 💪💪💪💪💪💪💪💪💪💪💪💪

	:return: divider130
	"""

	return divider130

def div131():
	"""
	Returns the divider 🐶🐶🐶🐶🐶🐶🐶🐶🐶🐶🐶🐶

	:return: divider131
	"""

	return divider131

def div132():
	"""
	Returns the divider 🐱🐱🐱🐱🐱🐱🐱🐱🐱🐱🐱🐱

	:return: divider132
	"""

	return divider132

def div133():
	"""
	Returns the divider 🐭🐭🐭🐭🐭🐭🐭🐭🐭🐭🐭🐭

	:return: divider133
	"""

	return divider133

def div134():
	"""
	Returns the divider 🐹🐹🐹🐹🐹🐹🐹🐹🐹🐹🐹🐹

	:return: divider134
	"""

	return divider134

def div135():
	"""
	Returns the divider 🐰🐰🐰🐰🐰🐰🐰🐰🐰🐰🐰🐰

	:return: divider135
	"""

	return divider135

def div136():
	"""
	Returns the divider 🦊🦊🦊🦊🦊🦊🦊🦊🦊🦊🦊🦊

	:return: divider136
	"""

	return divider136

def div137():
	"""
	Returns the divider 🐻🐻🐻🐻🐻🐻🐻🐻🐻🐻🐻🐻

	:return: divider137
	"""

	return divider137

def div138():
	"""
	Returns the divider 🐼🐼🐼🐼🐼🐼🐼🐼🐼🐼🐼🐼

	:return: divider138
	"""

	return divider138

def div139():
	"""
	Returns the divider 🐨🐨🐨🐨🐨🐨🐨🐨🐨🐨🐨🐨

	:return: divider139
	"""

	return divider139

def div140():
	"""
	Returns the divider 🐯🐯🐯🐯🐯🐯🐯🐯🐯🐯🐯🐯

	:return: divider140
	"""

	return divider140

def div141():
	"""
	Returns the divider 🦁🦁🦁🦁🦁🦁🦁🦁🦁🦁🦁🦁

	:return: divider141
	"""

	return divider141

def div142():
	"""
	Returns the divider 🐮🐮🐮🐮🐮🐮🐮🐮🐮🐮🐮🐮

	:return: divider142
	"""

	return divider142

def div143():
	"""
	Returns the divider 🐷🐷🐷🐷🐷🐷🐷🐷🐷🐷🐷🐷

	:return: divider143
	"""

	return divider143

def div144():
	"""
	Returns the divider 🐸🐸🐸🐸🐸🐸🐸🐸🐸🐸🐸🐸

	:return: divider144
	"""

	return divider144

def div145():
	"""
	Returns the divider 🐵🐵🐵🐵🐵🐵🐵🐵🐵🐵🐵🐵

	:return: divider145
	"""

	return divider145

def div146():
	"""
	Returns the divider 🙈🙈🙈🙈🙈🙈🙈🙈🙈🙈🙈🙈

	:return: divider146
	"""

	return divider146

def div147():
	"""
	Returns the divider 🙉🙉🙉🙉🙉🙉🙉🙉🙉🙉🙉🙉

	:return: divider147
	"""

	return divider147

def div148():
	"""
	Returns the divider 🙊🙊🙊🙊🙊🙊🙊🙊🙊🙊🙊🙊

	:return: divider148
	"""

	return divider148

def div149():
	"""
	Returns the divider 🐒🐒🐒🐒🐒🐒🐒🐒🐒🐒🐒🐒

	:return: divider149
	"""

	return divider149

def div150():
	"""
	Returns the divider 🐧🐧🐧🐧🐧🐧🐧🐧🐧🐧🐧🐧

	:return: divider150
	"""

	return divider150

def div151():
	"""
	Returns the divider 🐔🐔🐔🐔🐔🐔🐔🐔🐔🐔🐔🐔

	:return: divider151
	"""

	return divider151

def div152():
	"""
	Returns the divider 🐦🐦🐦🐦🐦🐦🐦🐦🐦🐦🐦🐦

	:return: divider152
	"""

	return divider152

def div153():
	"""
	Returns the divider 🐤🐤🐤🐤🐤🐤🐤🐤🐤🐤🐤🐤

	:return: divider153
	"""

	return divider153

def div154():
	"""
	Returns the divider 🐣🐣🐣🐣🐣🐣🐣🐣🐣🐣🐣🐣

	:return: divider154
	"""

	return divider154

def div155():
	"""
	Returns the divider 🐥🐥🐥🐥🐥🐥🐥🐥🐥🐥🐥🐥

	:return: divider155
	"""

	return divider155

def div156():
	"""
	Returns the divider 🦆🦆🦆🦆🦆🦆🦆🦆🦆🦆🦆🦆

	:return: divider156
	"""

	return divider156

def div157():
	"""
	Returns the divider 💐💐💐💐💐💐💐💐💐💐💐💐

	:return: divider157
	"""

	return divider157

def div158():
	"""
	Returns the divider 🌷🌷🌷🌷🌷🌷🌷🌷🌷🌷🌷🌷

	:return: divider158
	"""

	return divider158

def div159():
	"""
	Returns the divider 🌹🌹🌹🌹🌹🌹🌹🌹🌹🌹🌹🌹

	:return: divider159
	"""

	return divider159

def div160():
	"""
	Returns the divider 🥀🥀🥀🥀🥀🥀🥀🥀🥀🥀🥀🥀

	:return: divider160
	"""

	return divider160

def div161():
	"""
	Returns the divider 🌺🌺🌺🌺🌺🌺🌺🌺🌺🌺🌺🌺

    :return: divider161
	"""

	return divider161

def div162():
	"""
	Returns the divider 🌸🌸🌸🌸🌸🌸🌸🌸🌸🌸🌸🌸

    :return: divider162
	"""

	return divider162

def div163():
	"""
	Returns the divider 🌼🌼🌼🌼🌼🌼🌼🌼🌼🌼🌼🌼

	:return: divider163
	"""

	return divider163

def div164():
	"""
	Returns the divider 🌻🌻🌻🌻🌻🌻🌻🌻🌻🌻🌻🌻

	:return: divider164
	"""

	return divider164

def div165():
	"""
	Returns the divider 🌞🌞🌞🌞🌞🌞🌞🌞🌞🌞🌞🌞

	:return: divider165
	"""

	return divider165

def div166():
	"""
	Returns the divider 🌝🌝🌝🌝🌝🌝🌝🌝🌝🌝🌝🌝

	:return: divider166
	"""

	return divider166

def div167():
	"""
	Returns the divider 🌛🌛🌛🌛🌛🌛🌛🌛🌛🌛🌛🌛

	:return: divider167
	"""

	return divider167

def div168():
	"""
	Returns the divider 🌜🌜🌜🌜🌜🌜🌜🌜🌜🌜🌜🌜

	:return: divider168
	"""

	return divider168

def div169():
	"""
	Returns the divider 🌚🌚🌚🌚🌚🌚🌚🌚🌚🌚🌚🌚

	:return: divider169
	"""

	return divider169

def div170():
	"""
	Returns the divider 🌟🌟🌟🌟🌟🌟🌟🌟🌟🌟🌟🌟

	:return: divider170
	"""

	return divider170

def div171():
	"""
	Returns the divider ✨✨✨✨✨✨✨✨✨✨✨✨

	:return: divider171
	"""

	return divider171

def div172():
	"""
	Returns the divider ⚡⚡⚡⚡⚡⚡⚡⚡⚡⚡⚡⚡

	:return: divider172
	"""

	return divider172

def div173():
	"""
	Returns the divider ☄️☄️☄️☄️☄️☄️☄️☄️☄️☄️☄️

	:return: divider173
	"""

	return divider173

def div174():
	"""
	Returns the divider 🔥🔥🔥🔥🔥🔥🔥🔥🔥🔥🔥

	:return: divider174
	"""

	return divider174

def div175():
	"""
	Returns the divider 🌪🌪🌪🌪🌪🌪🌪🌪🌪🌪🌪🌪

	:return: divider175
	"""

	return divider175

def div176():
	"""
	Returns the divider 🌈🌈🌈🌈🌈🌈🌈🌈🌈🌈🌈🌈

	:return: divider176
	"""

	return divider176

def div177():
	"""
	Returns the divider 🍗🍗🍗🍗🍗🍗🍗🍗🍗🍗🍗🍗

	:return: divider177
	"""

	return divider177

def div178():
	"""
	Returns the divider 🍖🍖🍖🍖🍖🍖🍖🍖🍖🍖🍖🍖

	:return: divider178
	"""

	return divider178

def div179():
	"""
	Returns the divider 🌭🌭🌭🌭🌭🌭🌭🌭🌭🌭🌭🌭

	:return: divider179
	"""

	return divider179

def div180():
	"""
	Returns the divider 🍔🍔🍔🍔🍔🍔🍔🍔🍔🍔🍔🍔

	:return: divider180
	"""

	return divider180

def div181():
	"""
	Returns the divider 🍟🍟🍟🍟🍟🍟🍟🍟🍟🍟🍟🍟

	:return: divider181
	"""

	return divider181

def div182():
	"""
	Returns the divider 🍕🍕🍕🍕🍕🍕🍕🍕🍕🍕🍕🍕

	:return: divider182
	"""

	return divider182

def div183():
	"""
	Returns the divider 🥪🥪🥪🥪🥪🥪🥪🥪🥪

	:return: divider183
	"""

	return divider183

def div184():
	"""
	Returns the divider 🍧🍧🍧🍧🍧🍧🍧🍧🍧🍧🍧

	:return: divider184
	"""

	return divider184

def div185():
	"""
	Returns the divider 🍨🍨🍨🍨🍨🍨🍨🍨🍨🍨

	:return: divider185
	"""

	return divider185

def div186():
	"""
	Returns the divider 🍦🍦🍦🍦🍦🍦🍦🍦🍦🍦🍦🍦

	:return: divider186
	"""

	return divider186

def div187():
	"""
	Returns the divider 🥧🥧🥧🥧🥧🥧🥧🥧🥧

	:return: divider187
	"""

	return divider187

def div188():
	"""
	Returns the divider 🍰🍰🍰🍰🍰🍰🍰🍰🍰🍰🍰

	:return: divider188
	"""

	return divider188

def div189():
	"""
	Returns the divider 🎂🎂🎂🎂🎂🎂🎂🎂🎂🎂

	:return: divider189
	"""

	return divider189

def div190():
	"""
	Returns the divider 🍺🍺🍺🍺🍺🍺🍺🍺🍺🍺🍺

	:return: divider190
	"""

	return divider190

def div191():
	"""
	Returns the divider 🍻🍻🍻🍻🍻🍻🍻🍻🍻🍻🍻

	:return: divider191
	"""

	return divider191

def div192():
	"""
	Returns the divider 🥂🥂🥂🥂🥂🥂🥂🥂🥂🥂🥂🥂

	:return: divider192
	"""

	return divider192

def div193():
	"""
	Returns the divider 🍷🍷🍷🍷🍷🍷🍷🍷🍷🍷🍷🍷

	:return: divider193
	"""

	return divider193

def div194():
	"""
	Returns the divider ⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽⚽

	:return: divider194
	"""

	return divider194

def div194():
	"""
	Returns the divider 🥇🥇🥇🥇🥇🥇🥇🥇🥇🥇🥇🥇

	:return: divider194
	"""

	return divider194

def div195():
	"""
	Returns the divider 🚗🚗🚗🚗🚗🚗🚗🚗🚗🚗🚗🚗

	:return: divider195
	"""

	return divider195

def div196():
	"""
	Returns the divider ⏰⏰⏰⏰⏰⏰⏰⏰⏰⏰⏰⏰

	:return: divider196
	"""

	return divider196

def div197():
	"""
	Returns the divider 💰💰💰💰💰💰💰💰💰💰💰💰

	:return: divider197
	"""

	return divider197

def div198():
	"""
	Returns the divider 🎈🎈🎈🎈🎈🎈🎈🎈🎈🎈🎈🎈

	:return: divider198
	"""

	return divider198

def div199():
	"""
	Returns the divider ❤️❤️❤️❤️❤️❤️❤️❤️❤️❤️


	:return: divider199
	"""

	return divider199

def div200():
	"""
	Returns the divider 😨😨😨😨😨😨😨😨😨😨😨😨

	:return: divider200
	"""

	return divider200

def customdiv():
    return custom_div

def make_div(unit: str, length: int = 24, start: str = '', end: str = '', literal_unit=False) -> str:
    """
    Generates and returns a custom divider

    :param unit: str containing a repeating unit
    :param length: The maximum length that will not be exceeded (default: 24)
    :param start: optional starting string
    :param end: optional ending string
    :param literal_unit: if True will not try to break unit down into smaller repeating subunits
    :return: a custom created divider
    :rtype: str

    :Example:

    custom_div = make_div(unit='=-', length=40, start='<', end='=>')

    note:: The generated string will be terminated at the specified length regardless
     of whether all the input strings have been fully replicated.  A unit > 1 length may
     not be able to be replicated to extend to the full length.  In this situation, the
     string will be shorter than the specified length.

     Example: unit of 10 characters and a specified length of 25 will contain 2 units for
      a total length of 20 characters.
    """

    # reduce the size if possible to extend closer to full length
    if not literal_unit:
        unit = _reduce_to_unit(unit)
    repeats = (length - len(start + end)) // len(unit)

    return (start + unit * repeats + end)[0:length]


# reduces a repeating divider to the smallest repeating unit possible
# example: 'XxXxXxX' -> 'Xx'
def _reduce_to_unit(divider: str) -> str:
    for unit_size in range(1, len(divider) // 2 + 1):
        length = len(divider)
        unit = divider[:unit_size]
        remainder = length % unit_size

        # ignores mismatches in final characters
        if unit * (length // unit_size) == divider[:unit_size * (length // unit_size)]:
            return unit
    return divider  # return original if smaller unit not found


def area4info():
    info = f"Name: {name}"
    info += f"\nAuthor: {author}"
    info += f"\nAuthor Email: {author_email}"
    info += f"\nDescription: {description}"
    return info



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="area4",
    version="1.1.9",
    author="RDIL",
    author_email="contactspaceboom@gmail.com",
    description="Dividers in Python, the easy way! Many different divider looks.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/RDIL/area4",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Development Status :: 5 - Production/Stable',
        'Natural Language :: English',
    ],
    project_urls={
        "Bug Tracker": "https://github.com/RDIL/area4/issues",
        "Documentation": "https://area4.readthedocs.io/en/latest",
        "Source Code": "https://github.com/RDIL/area4",
    },
    keywords=["area4", "dividers", "python", "utilities"],
    include_package_data=True
)
